/**********************************************************************

	Command:  LOADOPT -- Load Drawing Option Setup Dialog

	Programmed by Kang, Hsin-Min.
	Released at Jul 04, 1997
	Revised at Oct 19, 1997, Add Help Buttons
	Revised at Apr 22, 1998 Include Japenese Text in SJIS codes

	Copyright (c) 1997, TCAM Development House, Taipei
	All rights Reserved.

	Status: Standard Command, with full support.

	The following options are setup by this commands:

	AutoAudit option
	BlockCtrl option
	Remove EMPTY BLOCK option
	DWGINPURGE option

***********************************************************************/
int	IsWin;
int	nSupport=identify("wnd_resize");
// Certain functions are supported only in Windows version and after
// wnd_resize(), so checking this will help to identify these supports.
//
//	Copy System variables to local variable for editing
//
int	autoaudit=@autoaudit;
int	dwginpurge=@dwginpurge;
int	noemptyblk=@noemptyblk;
int	blockctrl=@blockctrl;
//
int	nMain[6]={6,0x800|21,10,72,0x3270,0x8000};
int	widMain;	// Main Dialog Window ID
int	nTatrb=0x2f0;
int	nSatrb=0x270;
int	bAudit;
int	bNoDup;
int	bNoEBlk;
int	bPurge0;
int	bPurge1;
int	bPurge2;
int	bOK;
int	bCancel;
int	bHelp=0;

char	szText[15][40]; // Our display text buffer, see SetMsgText()
			// at the end of this file

// Macro to update variable with Undo consideration.
#define savevar(name)	if (name!=@name) { set_undo("name"); @name=name;}

COMMAND LoadOpt()
{
	IsWin = 1;
	switch(1) {  // Test if we are in TwinCAD ...
	  case !identify("os_type"):
	  case (os_type()<0):	// Must be in DOS version!
		IsWin = 0;
		break;
	}
	SetMsgText();
	if ( DoLoadOpt() ) {	// Ok, update these variables
		savevar(autoaudit);
		savevar(dwginpurge);
		savevar(noemptyblk);
		savevar(blockctrl);
	}
}

int	DoLoadOpt()
{
	int	nBtn;
	int	which;

	OpenDialog();
	UpdateDialog();
	for(;;) {
		nBtn = wnd_gbtn(0);
		switch(nBtn) {
		  case -3:
		  case -2:
		  case -1:
		  case	0:
			CloseDialog();
			return 0;
		  case bAudit:
			autoaudit = !autoaudit;
			wnd_fmark(bAudit,0,(autoaudit)?0x8000:0x80ff);
			continue;
		  case bNoDup:
			blockctrl ^= 1;
			wnd_fmark(bNoDup,0,(blockctrl&1)?0x8000:0x80ff);
			continue;
		  case bNoEBlk:
			noemptyblk = !noemptyblk;
			wnd_fmark(bNoEBlk,0,(noemptyblk)?0x8000:0x80ff);
			continue;
		  case bPurge0:
		  case bPurge1:
		  case bPurge2:
			dwginpurge = nBtn-bPurge0;
			wnd_fmark(bPurge0,1,(dwginpurge==0)?0x8000:0x80ff);
			wnd_fmark(bPurge1,1,(dwginpurge==1)?0x8000:0x80ff);
			wnd_fmark(bPurge2,1,(dwginpurge==2)?0x8000:0x80ff);
			continue;
		  case bHelp:
			show_help("","LOADOPT");
			continue;
		  case bCancel:
			CloseDialog();
			return 0;
		  case bOK:
			CloseDialog();
			return 1;
		}
	}
}
//
//	OpenDialog() -- Open main dialog window, create screen items.
//
void	OpenDialog()
{
	int	rBase, cBase, col;
	int	rInc=0x0801;
	widMain = wndopen(nMain,szText[0]/*"Drawing Load Option Setup Dialog"*/,0x3f1f,nMain[5]);
	WndGroup(0x0800,2,43,5,szText[1]/*"At Loading WRK/DWG/DXF File"*/,0x271);
	rBase = 2;
	cBase = 4;
	bAudit = WndCheckBox(rBase+rInc*0,cBase,szText[2]/*"Audit Drawing Automatically"*/,nSatrb);
	bNoDup = WndCheckBox(rBase+rInc*1,cBase,szText[3]/*"Ignore All Duplicated Blocks"*/,nSatrb);
	rBase += rInc*2;
	WndGroup(rBase,3,43,5,szText[4]/*"DWG/DXF Specific"*/,0x271);
	rBase += 0x0801;
	cBase = 5;
	bNoEBlk= WndCheckBox(rBase+rInc*0,cBase,szText[5]/*"Remove Empty Blocks"*/,nSatrb);
	rBase += rInc*1;
	WndGroup(rBase,4,43,5,szText[6]/*"DWG Specific"*/,0x271);
	rBase += 0x0801;
	cBase = 6;
	bPurge0 = WndRadioBox(rBase+rInc*0,cBase,szText[7]/*"Do not purge off unreferenced blocks"*/,nSatrb);
	bPurge1 = WndRadioBox(rBase+rInc*1,cBase,szText[8]/*"Query on each unreferenced block"*/,nSatrb);
	bPurge2 = WndRadioBox(rBase+rInc*2,cBase,szText[9]/*"Purge all unreferenced blocks"*/,nSatrb);

	rBase = 0x0801;
	cBase = 50;
	rInc = 0x0001;
	bOK	= WndButton(rBase+rInc*0,cBase,0x108,szText[10]/*"   OK   "*/);
	bCancel = WndButton(rBase+rInc*2,cBase,0x108,szText[11]/*" Cancel "*/);
    if ( IsWin )
	bHelp	= WndButton(rBase+rInc*4,cBase,0x108,szText[12]/*"  Help  "*/);
}
//
void	UpdateDialog()
{
	wnd_fmark(bAudit,0,(autoaudit)?0x8000:0x80ff);
	wnd_fmark(bNoDup,0,(blockctrl&1)?0x8000:0x80ff);
	wnd_fmark(bNoEBlk,0,(noemptyblk)?0x8000:0x80ff);
	wnd_fmark(bPurge0,1,(dwginpurge==0)?0x8000:0x80ff);
	wnd_fmark(bPurge1,1,(dwginpurge==1)?0x8000:0x80ff);
	wnd_fmark(bPurge2,1,(dwginpurge==2)?0x8000:0x80ff);
}
//
//	CloseDialog() -- Close the main dialog window, save window attribute
//
void	CloseDialog()
{
	wndclose();
}
//
//	WndGroup() -- Create Groupping window effect
//
void	WndGroup(int r,int c,int width, int height, char text[], int color)
{
	wnd_loct(r,c);
	wnd_rloct(height,0);
	wnd_field(0,0x370,(height<<8)|width);
	wnd_itemno(1,-1);
	wnd_rloct(-height,2);
	if ( !IsWin )
		wnd_rloct(0xfc00,0);
	put3Dstr(text,color);
	wnd_loct(r,c);	      // Reset row offset, fix DOS version bug
}
//
//	put3Dstr() -- Drawing 3D text
//
void	put3Dstr(char str[],int atrb)
{
	int	nLen;
	if ( nSupport ) {
		wnd_puts(str,atrb|0x300);
		return;
	}
	nLen=len(str);
	if ( nLen ) {
		wnd_rloct(0x100,IsWin?0x100:0);
		wnd_puts(str,(atrb^0x0f));
		wnd_rloct(0xff00,-nLen);
		wnd_puts(str,(atrb&0xff0f)|0x8000);
	}
}
//
//	WndCheckBox() -- Create window check box
//
int	WndCheckBox(int r,int c,char text[],int atrb)
{
	int	bID;
	if ( nSupport )
		return wnd_rcbox(r,c,text,0);
	wnd_loct(r,c);
	bID = wnd_field(1,0x1f0,0x102);
	wnd_rloct(0,2);
	if ( IsWin )  atrb |= 0x800;
	wnd_puts(text,atrb);
	return bID;
}
//
//	WndRadioBox() -- Create window radio box
//
int	WndRadioBox(int r,int c,char text[],int atrb)
{
	int	bID;
	if ( nSupport )
		return wnd_rcbox(r,c,text,0x8000);
	wnd_loct(r,c);
	bID = wnd_field(1,0x1f0,0x102);
	wnd_rloct(0,2);
	if ( IsWin ) atrb |= 0x800;
	wnd_puts(text,atrb);
	wnd_fmark(bID,1,IsWin?1:0x8000);     // Force to change state
	wnd_fmark(bID,1,IsWin?0:0x80ff);
	return bID;
}
//
int	WndButton(int r,int c, int bsize, char text[])
{
	int	i;
	if ( nSupport ) 	// Having direct support ?
		return wnd_button(r,c,bsize,0x1277,text);
	wnd_loct(r,c);
	i = wnd_field(0,IsWin?0x1277:0x370,bsize);
	wnd_puts(text,0x270);
	return i;
}

char	szAsciiText[][40]={	    // Default English Display Text
/*  0 */   "Drawing Load Option Setup Dialog",
/*  1 */   "At Loading WRK/DWG/DXF File",
/*  2 */   "Audit Drawing Automatically",
/*  3 */   "Ignore All Duplicated Blocks",
/*  4 */   "DWG/DXF Specific",
/*  5 */   "Remove Empty Blocks",
/*  6 */   "DWG Specific",
/*  7 */   "Do not purge off unreferenced blocks",
/*  8 */   "Query on each unreferenced block",
/*  9 */   "Purge all unreferenced blocks",
/* 10 */   "&OK",
/* 11 */   "&Cancel",
/* 12 */   "&Help",
};

char	szBig5Text[][40]={	   // Default Chinese Big-5 Display Text
/*  0 */   "ɸJ\\ﶵ]w",
/*  1 */   "bJ WRK/DWG/DXF ɮ...",
/*  2 */   "۰ʽ]ֹɹϤT.",
/*  3 */   "۰ʩPWϲթwq.",
/*  4 */   "J DWG/DXF ɪSwﶵ",
/*  5 */   "۰ʮŪϲթwq.",
/*  6 */   "JDWG ɪSwﶵ",
/*  7 */   "n۰ʰQ٪ϲ, qqJ.",
/*  8 */   "NQ٪ϲդ@@ӧO߰ݬO_.",
/*  9 */   "۰ʰҦQ٪ϲ",
/* 10 */   "Tw[&O]",
/* 11 */   "[&C]",
/* 12 */   "[&H]",
};

char	szGB2312Text[][40]={	// Default Chinese GB2312 Display Text
/*  0 */   "ͼ빦\ѡ趨",
/*  1 */   " WRK/DWG/DXF ͼʱ...",
/*  2 */   "ԶͼͼԪȷ.",
/*  3 */   "Զͬͼ鶨.",
/*  4 */   " DWG/DXF ʱضѡ",
/*  5 */   "Զյͼ鶨.",
/*  6 */   "DWG ʱضѡ",
/*  7 */   "ҪԶδָƵͼ, ͨͨ.",
/*  8 */   "δָƵͼһһѯǷ.",
/*  9 */   "ԶδָƵͼ",
/* 10 */   "ȷ[&O]",
/* 11 */   "ȡ[&C]",
/* 12 */   "˵[&H]",
};
//
//	The following Japenese messages are translated by _____________.
//
char	szSJISText[][40]={    // Default Japenese SJIS Display Text
/*  0 */   "}ʓǍ̏ڍאݒ",
/*  1 */   "Ǎ̧  WRK/DWG/DXF ̧ ",
/*  2 */   "}ʂ̎",
/*  3 */   "dۯ͖",
/*  4 */   "DWG/DXF `",
/*  5 */   "gpۯ͍폜",
/*  6 */   "DWG `",
/*  7 */   "gpۯ폜Ȃ",
/*  8 */   "gpۯ͊mF폜",
/*  9 */   "gpۯ폜",
/* 10 */   "&OK",
/* 11 */   "ݾ[&C]",
/* 12 */   "[&H]",
};
//
//	The following Korean messages are translated by _____________.
//
char	szKoreanText[][40]={	// Default Korean Display Text
/*  0 */   "Drawing Load Option Setup Dialog",
/*  1 */   "At Loading WRK/DWG/DXF File",
/*  2 */   "Audit Drawing Automatically",
/*  3 */   "Ignore All Duplicated Blocks",
/*  4 */   "DWG/DXF Specific",
/*  5 */   "Remove Empty Blocks",
/*  6 */   "DWG Specific",
/*  7 */   "Do not purge off unreferenced blocks",
/*  8 */   "Query on each unreferenced block",
/*  9 */   "Purge all unreferenced blocks",
/* 10 */   "&OK",
/* 11 */   "&Cancel",
/* 12 */   "&Help",
};

char	szDosAsciiText[][40]={	       // Default English Display Text
/*  0 */   "Drawing Load Option Setup Dialog",
/*  1 */   "At Loading WRK/DWG/DXF File",
/*  2 */   "Audit Drawing Automatically",
/*  3 */   "Ignore All Duplicated Blocks",
/*  4 */   "DWG/DXF Specific",
/*  5 */   "Remove Empty Blocks",
/*  6 */   "DWG Specific",
/*  7 */   "Do not purge off unreferenced blocks",
/*  8 */   "Query on each unreferenced block",
/*  9 */   "Purge all unreferenced blocks",
/* 10 */   "   OK   ",
/* 11 */   " Cancel ",
/* 12 */   "  Help  ",
};
char	szDosBig5Text[][40]={	      // Default Chinese Big-5 Display Text
/*  0 */   "ɸJ\\ﶵ]w",
/*  1 */   "bJ WRK/DWG/DXF ɮ...",
/*  2 */   "۰ʽ]ֹɹϤT.",
/*  3 */   "۰ʩPWϲթwq.",
/*  4 */   "J DWG/DXF ɪSwﶵ",
/*  5 */   "۰ʮŪϲթwq.",
/*  6 */   "JDWG ɪSwﶵ",
/*  7 */   "n۰ʰQ٪ϲ, qqJ.",
/*  8 */   "NQ٪ϲդ@@ӧO߰ݬO_.",
/*  9 */   "۰ʰҦQ٪ϲ",
/* 10 */   "  Tw  ",
/* 11 */   "    ",
/* 12 */   "  Help  ",
};

char	szDosGB2312Text[][40]={    // Default Chinese GB2312 Display Text
/*  0 */   "ͼ빦\ѡ趨",
/*  1 */   " WRK/DWG/DXF ͼʱ...",
/*  2 */   "ԶͼͼԪȷ.",
/*  3 */   "Զͬͼ鶨.",
/*  4 */   " DWG/DXF ʱضѡ",
/*  5 */   "Զյͼ鶨.",
/*  6 */   "DWG ʱضѡ",
/*  7 */   "ҪԶδָƵͼ, ͨͨ.",
/*  8 */   "δָƵͼһһѯǷ.",
/*  9 */   "ԶδָƵͼ",
/* 10 */   "  ȷ  ",
/* 11 */   "  ȡ  ",
/* 12 */   "  Help  ",
};
//
//	The following Japenese messages are translated by _____________.
//
char	szDosSJISText[][40]={	 // Default Japenese SJIS Display Text
/*  0 */   "}ʓǍ̏ڍאݒ",
/*  1 */   "Ǎ̧ WRK/DWG/DXF ̧",
/*  2 */   "}ʂ̎",
/*  3 */   "dۯ͖",
/*  4 */   "DWG/DXF `",
/*  5 */   "gpۯ͍폜",
/*  6 */   "DWG `",
/*  7 */   "gpۯ폜Ȃ",
/*  8 */   "gpۯ͊mF폜",
/*  9 */   "gpۯSč폜",
/* 10 */   "   OK   ",
/* 11 */   "  ݾ ",
/* 12 */   "    ",
};
//
//	The following Korean messages are translated by _____________.
//
char	szDosKoreanText[][40]={    // Default Korean Display Text
/*  0 */   "Drawing Load Option Setup Dialog",
/*  1 */   "At Loading WRK/DWG/DXF File",
/*  2 */   "Audit Drawing Automatically",
/*  3 */   "Ignore All Duplicated Blocks",
/*  4 */   "DWG/DXF Specific",
/*  5 */   "Remove Empty Blocks",
/*  6 */   "DWG Specific",
/*  7 */   "Do not purge off unreferenced blocks",
/*  8 */   "Query on each unreferenced block",
/*  9 */   "Purge all unreferenced blocks",
/* 10 */   "   OK   ",
/* 11 */   " Cancel ",
/* 12 */   "  Help  ",
};

#define BIG5		0x404
#define GB2312		0x804
#define SJIS		0x411
#define KOREAN		0x412
#define ASCII		0x409

#define TGBIG5		1
#define TGGB2312	2
#define TGSJIS		5
#define TGKOREAN	3

int	SetMsgText()
{
	char	szBuf[80];
	int	switched;

	IsWin = 1;
	switch(1) {  // Test if we are in TwinCAD ...
	  case !identify("os_type"):
	  case (os_type()<0):	// Must be in DOS version!
		IsWin = 0;
		break;
	}

	if ( IsWin ) {
	    szBuf = get_profile("General Setup","AlternateLanguage");
	    switched = 0;
	    if ( szBuf!="" )
		switched = eval(szBuf);
	    if ( switched ) {
		switch(os_language()) {
		  case BIG5:	setdata(szText,szBig5Text);	break;
		  case GB2312:	setdata(szText,szGB2312Text);	break;
		  case SJIS:	setdata(szText,szSJISText);	break;
		  case KOREAN:	setdata(szText,szKoreanText);	break;
		  default:	setdata(szText,szAsciiText);	break;
		}
	    }
	    else
		setdata(szText,szAsciiText);
	}
	else {	// Switched or not, depends on TGF type in DOS version
	    switch(@tgftype) {
	      case TGBIG5:    setdata(szText,szDosBig5Text);	 break;
	      case TGGB2312:  setdata(szText,szDosGB2312Text);	 break;
	      case TGSJIS:    setdata(szText,szDosSJISText);	 break;
	      case TGKOREAN:  setdata(szText,szDosKoreanText);	 break;
	      default:	      setdata(szText,szDosAsciiText);	 break;
	    }
	}
	return 0;
}
//
//	End of this Program file
//
